A list of get functions for aquatic mosquito modules.
get_L_vars– get state variables from \(y\)get_L_ix– get variable indicesget_L_inits– get initial valuesget_L_pars– get parametersget_L_orbits– get saved orbits
A list of get functions for aquatic mosquito modules.
get_L_vars – get state variables from \(y\)
get_L_ix – get variable indices
get_L_inits – get initial values
get_L_pars – get parameters
get_L_orbits – get saved orbits