A list of setup functions for aquatic mosquito modules.
setup_L_obj– set up the L module objectsetup_L_ix– set up variable indicessetup_L_inits– set up initial values
A list of setup functions for aquatic mosquito modules.
setup_L_obj – set up the L module object
setup_L_ix – set up variable indices
setup_L_inits – set up initial values