Skip to contents

A List of Available Modules for the MY-Component from ramp.xds and ramp.library

In ramp.xds

  • trivial - the trivial module: see trivial_MY

  • SI - an SI compartmental model: see SI

  • macdonald - an implementation of Macdonald's model: see macdonald

  • GeM - A generalized Macdonald model: see GeM

  • basicM - A basic model for mosquito ecology: see basicM

  • RMdts - A Discrete Time Macdonald model: see RMdts

In ramp.library

ramp.library source code & github.io

  • SEI - A compartmental model

  • BQ - A behavioral state model with blood feeding, egg laying, and infection dynamics

  • BQm - A behavioral state model with blood feeding & egg laying (M only)

  • BQRS - A behavioral state model with blood feeding, egg laying, resting, sugar feeding and infection dynamics