R/variables.R
Other_State_Variables.Rd
For extensibility, ramp.xds is capable of setting up and computing other state variables, or dependent variables that are not part of one of the core dynamical components.
ramp.xds
variables