This calls MEffectSizes and LEffectSizes for each species. This function applies the effect sizes of vector control to the bionomic parameters for each vector species.
Value
a list
This calls MEffectSizes and LEffectSizes for each species. This function applies the effect sizes of vector control to the bionomic parameters for each vector species.
a list