The initial values are stored on the L object as a
named list called inits; get_L_inits returns that list.
Value
a named list
The initial values are stored on the L object as a
named list called inits; get_L_inits returns that list.
a named list