Skip to contents

The indices are stored on the L object as a named list called ix; get_L_ix returns that list.

Usage

get_L_ix(xds_obj, s = 1)

Arguments

xds_obj

an xds model object

s

the vector species index

Value

a named list of indices for the L variables