This method dispatches on the type of xds_obj$MY_obj.
It computes the variables by name and returns a named list.
Arguments
- outputs
a matrix of outputs from deSolve
- xds_obj
an
xdsmodel object- s
the vector species index
This method dispatches on the type of xds_obj$MY_obj.
It computes the variables by name and returns a named list.
a matrix of outputs from deSolve
an xds model object
the vector species index