Set the parameter values and configure a model for the X Component
Usage
setup_XH_obj(Xname, residence, HPop, xds_obj, i, options = list())Set the parameter values and configure a model for the X Component
setup_XH_obj(Xname, residence, HPop, xds_obj, i, options = list())