Skip to contents

Adds port objects and default values for the time spent matrix, time away, and blood feeding search weights.

Usage

setup_XH_ports(xds_obj, i)

Arguments

xds_obj

an xds model object

i

the host species index

Value

an xds object