For a model with temporal forcing, show the perturbation function
Usage
show_shock(xds_obj, tm = 10 * c(0:365), add = FALSE, clr = "black", rng = NULL)For a model with temporal forcing, show the perturbation function
show_shock(xds_obj, tm = 10 * c(0:365), add = FALSE, clr = "black", rng = NULL)