Skip to contents

Heterogeneous biting rates are closely related to relative biting rates: for a stratum, the relative biting rate is a value \(\omega\) such that if the population average daily EIR is \(E\), then the daily EIR for the stratum is \(\omega E\).

Models for heterogeneous biting are constructed by passing blood search weights for human population strata, \(w\). If the time spent in a patch is \(\theta\), then the availability of humans in that patch is is: $$W_j = \sum_i w_i \theta_{i,j} H_i.$$ The fraction of bites received by the \(i^{th}\) stratum in patch \(j\) is: $$\frac{w_i \theta_{i,j} H_i}{W_j}$$ The daily EIR is: $$E_i = w_i \sum_j \frac{\theta_{i,j} }{W_j}f_j q_j Z_j$$ The population average EIR is $$E = \sum_i E_i H_i/ \sum_i H_i$$ The relative biting rate is $$\omega_i = E_i / E$$