In ramp.xds, clusters of ports are sometimes bundled
into a junction (see xds_info_port). A junction is a structural element,
a function that is designed to handle one or more ports.
Other_State_Variables – a junction to add new state variables, effectively extending the dynamical system
xds_info_forcing – a junction to handle exogenous forcing by weather, etc.
xds_info_vector_control – a junction to handle vector control
xds_info_health – a junction to handle vector control
xds_info_resources – a junction to handle resource dynamics
xds_info_importation – a junction to handle resource dynamics