The XY - interface has a port for the availability of other blood hosts, defined as any vertebrate host that attracts blood feeding mosquitoes but that are not defined
The XY - interface has a port for the availability of other blood hosts, defined as any vertebrate host that attracts blood feeding mosquitoes but that are not defined