Skip to contents

A modified version of xds_setup to setup up studies of malaria epidemiology, defined in a narrow sense, to examine patterns in populations forced by the EIR.

The xds object defines frame = class(frame) = 'eir' to dispatch functions that compute derivatives (xde), update variables (dts), and parse outputs

The interface includes options to configure a function describing F_eir as a function of time, with seasonal components and a trend.

This can be used to model a cohort as it ages; a function is set up to modify exposure by age.

Usage

xds_setup_eir(
  model_name = "unnamed",
  eir = 1,
  F_season = F_one,
  F_trend = F_one,
  F_shock = F_one,
  F_age = F_one,
  season_par = list(name = "F_one"),
  trend_par = list(name = "F_one"),
  age_par = list(name = "F_one"),
  shock_par = list(name = "F_one"),
  xds = "ode",
  Xname = "SIS",
  XHoptions = list(),
  HPop = 1000,
  searchB = 1
)

Arguments

model_name

is a name for the model (arbitrary)

eir

is the entomological inoculation rate

F_season

the seasonal pattern function

F_trend

the trend function

F_shock

the shock function

F_age

the relative biting rate by age

season_par

a list of options for F_season

trend_par

a list of options for F_trend

age_par

a list of options for F_age

shock_par

a list of options for F_shock

xds

is ode or dde or dts for ordinary OR delay differential OR difference equations

Xname

is a character string specifying an X Component module

XHoptions

a list to configure the X Component module

HPop

is the number of humans in each stratum

searchB

is a vector of search weights for blood feeding

Value

an xds object

See also