A List of Available Modules for the MY-Component from ramp.xds and ramp.library
In ramp.xds
trivial- the trivial module: see trivial_MYSI- an SI compartmental model: see SImacdonald- an implementation of Macdonald's model: see macdonaldGeM- A generalized Macdonald model: see GeMbasicM- A basic model for mosquito ecology: see basicMRMdts- A Discrete Time Macdonald model: see RMdts
In ramp.library
ramp.library source code & github.io
SEI- A compartmental modelBQ- A behavioral state model with blood feeding, egg laying, and infection dynamicsBQm- A behavioral state model with blood feeding & egg laying (M only)BQRS- A behavioral state model with blood feeding, egg laying, resting, sugar feeding and infection dynamics