In the SIS compartmental model, infected individuals are either susceptible (S), or infected and infectious (I). Susceptible individuals become infected at the per-capita rate \(h\). Infected individuals clear infections at the per-capita rate \(r\), and then they become susceptible to infection again.
Human/host population size (H) is a state variable that can be configured.
and \(H=S+I\): the model computes \(dH/dt\) and \(dI/dt\). When outputs are parsed, S is computed as \(S=H-I\).
This module also includes:
a model for human demographic changes; and
a port for mass treatment, \(\xi(t)\).
State Variables
Htotal human (or host) population density
Idensity of infected humans
During parsing, the density of susceptibles is computed as: $$S = H - I$$.