The indices are stored on the L object as a
named list called ix; get_L_ix returns that list.
Value
a named list of indices for the L variables
The indices are stored on the L object as a
named list called ix; get_L_ix returns that list.
a named list of indices for the L variables