Using formulas, compute the \(N_p \times N_p\) matrix \([V]\) whose columns describe the number of infective bites arising in each patch from all the mosquitoes biting a single human on a single day in each patch.
Value
a numeric matrix
Using formulas, compute the \(N_p \times N_p\) matrix \([V]\) whose columns describe the number of infective bites arising in each patch from all the mosquitoes biting a single human on a single day in each patch.
a numeric matrix