Compute the \(N_p \times N_p\) matrix \(\mathcal{V}\) whose columns describe the number of infective bites arising in each patch from all the mosquitoes biting a single human on a single day in each patch.
Compute the VC matrix for models that use the parameter set for the generalized Macdonald model
Usage
# S3 method for class 'macdonald'
make_VC(xds_obj, s = 1)
make_VC_gem(xds_obj, s = 1)