Build a function that generates a time series with known functions. The value of variable \(x(t)\) is computed as a product of four configurable elements:
\(\bar x\): a mean value
\(S(t)\): a seasonal pattern
\(T(t)\): a trend
\(K(t)\): a shock
$$x(t) = \bar x \times S(t) \times T(t) \times K(t)$$
The component functions are specified by passing parameters for make_function:
season_parcreates \(S(t)\) orF_season(eg, using makepar_F_sin)trend_parcreates \(T(t)\) orF_trend(eg, using makepar_F_spline)shock_parcreates \(K(t)\) orF_shock(eg, using makepar_F_sharkbite)