R/human-ports.R
setup_XH_ports.Rd
Adds port objects and default values for the time spent matrix, time away, and blood feeding search weights.
setup_XH_ports(xds_obj, i)
an xds model object
xds
the host species index
an xds object