The trivial module outputs the emergence rate of adult mosquitoes by calling a trace function, $$F_\alpha(t) = \Lambda \times F_S(t, V_s) \times F_T(t, V_t) \times F_K(t, V_k)$$ where
\(\Lambda\) is the mean daily emergence rate of adult mosquitoes
\(F_S(t,V_s)\) or
F_seasonis a seasonal pattern function\(F_T(t,V_t)\) or
F_trendis a trend pattern function\(F_K(t,V_k)\) or
F_shockis a perturbation function
The variables \(V_s\), \(V_t\), and \(V_t\) are
called by get_variables, which dispatches on the class of
season_par or trend_par or shock_par.
Parameters
Lambdathe mean daily emergence rate
F_seasona seasonal pattern function, \({F_S(t,V_s)}\)
F_trenda trend function, \(F_T(t,V_t)\)
F_shocka shock function, \(F_K(t,V_k)\)
season_pardispatches get_variables to get \(V_s\)
trend_pardispatches get_variables to get \(V_t\)
shock_pardispatches get_variables to get \(V_k\)
The default values are F_season=F_trend=F_shock=F_one and the classes of the
objects season_par and trend_par and shock_par are all list
Get
get_L_pars— thetrivialmethod returns all the parametersget_mean_forcing— getLambdaget_season— returnsseason_parget_trend— returnstrend_parget_shock— returnsshock_par
Change
change_L_pars— change parameters by namechange_mean_forcing— changesLambdachange_season— changes elements ofseason_parchange_trend— changes elements oftrend_parchange_shock— changes elements ofshock_par
Notes
The module has no state variables.
The size of an object saved by
saveRDSballoons if it saves a function, sosaveXDSfunction strips the functions andreadRDSremakes the function from the stored parameters.F_season,F_trend, andF_shockcan be set up manually by passing any user defined function. If so, the user should usesaveRDSandreadRDSrather thansaveXDSandreadXDSSetup expects that
membership= c(1:nPatches),but any membership vector works.