The trivial module outputs the emergence rate of adult mosquitoes by calling a trace function, $$F_\alpha(t) = \Lambda S(t) T(t) K(t)$$ where
\(\Lambda\) or
Lambdais the mean number of adult female mosquitoes emerging per day\(S(t)\) or
F_seasonis a seasonal pattern\(T(t)\) or
F_trendis a trend pattern\(K(t)\) or
F_shockis a perturbation
Parameters
Lambdathe mean daily emergence rate
season_parparameters for make_function:
F_season=make_function(season_par)trend_parparameters for make_function:
F_trend=make_function(trend_par)shock_parparameters for make_function:
F_shock=make_function(shock_par)
The default setup option is season_par = trend_par = shock_par = makepar_F_one().
Get
get_L_pars— thetrivialmethod returns all the parametersget_mean_forcing— getLambdaget_season— returnsseason_parget_trend— returnstrend_parget_shock— returnsshock_par
Change
change_L_pars— change parameters by namechange_mean_forcing— changesLambdachange_season— changes elements ofseason_parchange_trend— changes elements oftrend_parchange_shock— changes elements ofshock_par
Notes
The module has no state variables.
The size of an object saved by
saveRDSballoons if it saves a function, sosaveXDSfunction strips the functions andreadRDSremakes the function from the stored parameters.F_season,F_trend, andF_shockcan be set up manually by passing any user defined function. If so, the user should usesaveRDSandreadRDSrather thansaveXDSandreadXDSSetup expects that
membership= c(1:nPatches),but any membership vector works.