The trivial MY module configures two trace functions:
infectious biting: $$F_{fqZ}(t, V) = fqZ \times F_S(t, V_s) \times F_T(t, V_t) \times F_K(t, V_k)$$
egg laying: $$F_G(t, V) = G \times F_S(t,V_s) \times F_T(t, V_t) \times F_K(t, V_k)$$
where
\(G\) or
eggsis the mean egg laying rate\(fqZ\) or
fqZis the mean number of infectious bites on humans, per patch\(F_S(t,V_s)\) or
F_seasonis a seasonal pattern function\(F_T(t,V_t)\) or
F_trendis a trend pattern function\(F_K(t,V_k)\) or
F_shockis a perturbation function
The variables \(V_s\), \(V_t\), and \(V_t\) are
called by get_variables, which dispatches on the class of
season_par or trend_par or shock_par.
The implementation assumes that only one of these functions gets used.
Parameters
eggsthe mean number of eggs laid, per day
Zthe mean density of infectious mosquitoes
fthe blood feeding rate
qthe human fraction
F_seasona seasonal pattern function, \({F_S(t,V_s)}\)
F_trenda trend function, \(F_T(t,V_t)\)
F_shocka shock function, \(F_K(t,V_k)\)
season_pardispatches get_variables to get \(V_s\)
trend_pardispatches get_variables to get \(V_t\)
shock_pardispatches get_variables to get \(V_k\)
The default values are F_season=F_trend=F_shock=F_one and the
classes of the objects season_par and trend_par and shock_par are all
'list'
For the bionomic parameters, f=q=Z=eggs=1.
Get
get_MY_pars— thetrivialmethod returns all the parametersget_mean_forcing— returnsZget_f— returnsfget_q— returnsqget_season— returnsseason_parget_trend— returnstrend_parget_shock— returnsshock_par
Note: use get_MY_pars to inspect eggs
Change
change_MY_pars— change bionomic parameters by namechange_mean_forcing— changesZchange_F_season— changesF_seasonchange_F_trend— changesF_trendchange_F_shock— changesF_shock
Notes
The module has no state variables.
The size of an object saved by
saveRDSballoons if it saves a function, sosaveXDSfunction strips the functions andreadRDSremakes the function from the stored parameters.
F_season, F_trend, and F_shock can be set up manually by passing any
user defined function. If so, the user should use saveRDS and readRDS
rather than saveXDS and readXDS