The trivial MY module configures two trace functions:
infectious biting: $$F_{fqZ}(t) = fqZ S(t) T(t) K(t)$$
egg laying: $$F_G(t) = G S(t) T(t) K(t)$$
where
\(G\) or
eggsis the mean egg laying rate\(fqZ\) or
fqZis the mean number of infectious bites on humans, per patch\(S(t)\) or
F_seasonis a seasonal pattern\(T(t)\) or
F_trendis a trend pattern\(K(t)\) or
F_shockis a perturbation
Parameters
eggsthe mean number of eggs laid, per day
Zthe mean density of infectious mosquitoes
fthe blood feeding rate
qthe human fraction
season_parparameters for make_function:
F_season=make_function(season_par)trend_parparameters for make_function:
F_trend=make_function(trend_par)shock_parparameters for make_function:
F_shock=make_function(shock_par)
The default setup options:
for the make_function parameters,
season_par = trend_par = shock_par = makepar_F_one().for the bionomic parameters,
f=q=Z=eggs=1.
Get
get_MY_pars— thetrivialmethod returns all the parametersget_mean_forcing— returnsZget_f— returnsfget_q— returnsqget_season— returnsseason_parget_trend— returnstrend_parget_shock— returnsshock_par
Note: use get_MY_pars to inspect eggs
Change
change_MY_pars— change parameters by namechange_mean_forcing— changesZchange_season— changes elements ofseason_parchange_trend— changes elements oftrend_parchange_shock— changes elements ofshock_par
Note: use change_MY_pars to change eggs
Notes
The module has no state variables.
The size of an object saved by
saveRDSballoons if it saves a function, sosaveXDSfunction strips the functions andreadRDSremakes the function from the stored parameters.F_season,F_trend, andF_shockcan be set up manually by passing any user defined function. If so, the user should usesaveRDSandreadRDSrather thansaveXDSandreadXDS