Mosquito dispersal is handled in a standard way across all MY modules.
A mosquito dispersal matrix, called \(K\) or
K_matrix, is set up using setup_K_matrix;\(K\) is used to make a mosquito demographic matrix, called \(\Omega\) or
Omega(see xds_info_mosquito_demography).
Setup
K_matrixeither a \(K\) matrix: or options for setup_K_matrix
There are several ways to configure \(K\) during basic setup.
By default: K_matrix is an empty list. When the MY_obj is set up, the \(K\)
matrix is set to diag(g), a model with no dispersal. That is not changed unless one of the
following holds:
Mosquito Dispersal Matrix, \(K\)
In adult mosquito modules, mosquito dispersal is described by
a square matrix \(K\) with nPatches \((=n)\) rows and columns. By convention,
all \(K\) matrices have the form:
$$
K = \left[ \begin{array}{ccccc}
-1 & k_{1,2} & k_{1,3} & \cdots & k_{1, n} \\
k_{2,1} & -1 & k_{2,3} & \cdots & k_{2, n} \\
k_{3,1} & k_{3,2} & -1 & \cdots & k_{3, n} \\
\vdots & \vdots & \vdots & \ddots & \vdots \\
k_{n,1} & k_{n,2} & k_{n,3} & \cdots & -1 \\
\end{array} \right]
$$
The values of the elements \(k_{i,j}\) are thus
constrained such that there is no net dispersal loss from the system: \(\forall i,\)
$$\sum_j k_{i,j} = 1.$$
The columns of \(K\) sum up to zero.
\(K\) thus describes the destinations of
emigrating mosquitoes that survive and stay in the system.
Emigration rates and emigration-related loss – emigration from the spatial domain and mortality that is conditioned on emigration – are handled separately (see xds_info_mosquito_demography).