After solving a system of equations using xds_solve, the outputs
are parsed and attached to xds_object$outputs.
Use get_*_orbits to inspect the orbits.
Note: xds_object$outputs are overwritten each time
xds_solve is called.
Internals
Each module defines a method
parse_*_orbitsxds_solve calls parse_outputs which calls
parse_*_orbitsfor each component and for each speciesOutputs are parsed and stored on the xds object as
xds_obj$outputstimeis stored asxds_obj$outputs$timethe full output matrix is stored as
xds_obj$outputs$deoutthe last state of the system is stored as
mod$outputs$last_yseveral dynamical terms (
EIR,PR,fqZ,kappa) are computed and attached as orbitsthe state variables are extracted from the output matrix by name
the terms and variables are attached as named lists to
xds_obj$outputs$orbits.XHholds parsed outputs for the XH componentMYholds parsed outputs for the MY componentLholds parsed outputs for the L component