Skip to contents

Basic Setup uses xds_setup or one of its variants (see xds_info_basic_setup) to create an xds object.

The following is a list of configurable options and where to look for more help.

Basic Setup uses xds_setup or one of its variants (see xds_info_basic_setup) to create an xds object.

The following is a list of configurable options and where to look for more help.

Structural Parameters

Modules

Parameter values and initial values for the variables are passed as named lists. The module help pages have information about how to configure: Xoptions, MYoptions, & Loptions.

Parameter values and initial values for the variables are passed as named lists. The module help pages have information about how to configure: Xoptions, MYoptions, & Loptions.