ramp.xds: All Setup Options
Source: R/xds_help_setup_options.R, R/xds_info-setup_options.R
xds_info_setup_options.RdBasic Setup uses xds_setup or one of its variants (see xds_info_basic_setup) to create an xds object.
The following is a list of configurable options and where to look for more help.
Basic Setup uses xds_setup or one of its variants (see xds_info_basic_setup) to create an xds object.
The following is a list of configurable options and where to look for more help.
Structural Parameters
nPatches– see xds_info_patch_dynamicsnStrata– see xds_info_human_populationsnHabitats– see xds_info_aquatic_habitats
nPatches– see xds_info_patch_dynamicsnStrata– see xds_info_human_populationsnHabitats– see xds_info_aquatic_habitats
Modules
Xname– see XH_module_listMYname– see MY_module_listLname– see L_module_list
Parameter values and initial values for the variables are
passed as named lists. The module help pages have information
about how to configure:
Xoptions,
MYoptions, &
Loptions.
Xname– see XH_module_listMYname– see MY_module_listLname– see L_module_list
Parameter values and initial values for the variables are
passed as named lists. The module help pages have information
about how to configure:
Xoptions,
MYoptions, &
Loptions.
Basic options
Koptionssee xds_info_mosquito_dispersal and setup_K_matrix