Compute the steady state for a system of differential equations.
Run for \(Y\) years
Check the sun of squared differences in the final state is less than
tolIf not
Compute the steady state for a system of differential equations.
Run for \(Y\) years
Check the sun of squared differences in the final state is less than tol
If not